==> eslint-plugin-module-import-plugin-0.0.1.tgz: package/lib/rules/path-checker.js <==
"use strict";

const path = require('path');

module.exports = {
  meta: {
    type: null, // `problem`, `suggestion`, or `layout`
    docs: {
      description: "feature sliced relative path checker",
      recommended: false,
      url: null, // URL to the documentation page for this rule
    },
    fixable: null, // Or `code` or `whitespace`
    schema: [], // Add a schema if the rule has options
  },

  create(context) {

    return {
      ImportDeclaration(node) {
        // example app/entities/Article
        const importTo = node.source.value

        // example C:\Users\impudev\Desktop\javascript\project\src\entities\Article
        const fromFilename = context.getFilename()

        if (shouldBeRelative(fromFilename, importTo)) {
          context.report(node, 'В рамках слайса пути должны быть относительными')
        }
      }
    };
  },
};

function isPathRelative(path) {
  return path === '.' || path.startsWith('./') || path.startsWith('../')
}

const layers = {
  'entities': 'entities',
  'features': 'features',
  'shared': 'shared',
  'pages': 'pages',
  'widgets': 'widgets',
}
function shouldBeRelative(from, to) {

  if(isPathRelative(to)) {
    return false
  }

  // example app/entities/Article
  const toArray = to.split('/')
  const toLayer = toArray[0]  // entities
  const toSlice = taArray[1]  // Article

  if(!toLayer || !toSlice || !layers[toLayer]) {
    return false
  }

  const normalizedPath = path.toNamespacedPath(from)
  const projectFrom = normalizedPath.split('src')[1]
  const fromArray = projectFrom.split('\\')
  const fromLayer = fromArray[1]
  const fromSlice = fromArray[2]

  if(!fromLayer || !fromSlice || !layers[fromLayer]) {
    return false
  }

  return fromSlice === toSlice && toLayer === fromLayer

  // example C:\Users\impudev\Desktop\javascript\project\src\entities\Article
  const fromFilename = context.getFilename()
}

==> eslint-plugin-module-import-plugin-0.0.2.tgz: package/lib/rules/path-checker.js <==
"use strict";

const path = require('path');

module.exports = {
  meta: {
    type: null, // `problem`, `suggestion`, or `layout`
    docs: {
      description: "feature sliced relative path checker",
      recommended: false,
      url: null, // URL to the documentation page for this rule
    },
    fixable: null, // Or `code` or `whitespace`
    schema: [], // Add a schema if the rule has options
  },

  create(context) {

    return {
      ImportDeclaration(node) {
        // example app/entities/Article
        const importTo = node.source.value

        // example C:\Users\impudev\Desktop\javascript\project\src\entities\Article
        const fromFilename = context.getFilename()

        if (shouldBeRelative(fromFilename, importTo)) {
          context.report(node, 'В рамках слайса пути должны быть относительными')
        }
      }
    };
  },
};

function isPathRelative(path) {
  return path === '.' || path.startsWith('./') || path.startsWith('../')
}

const layers = {
  'entities': 'entities',
  'features': 'features',
  'shared': 'shared',
  'pages': 'pages',
  'widgets': 'widgets',
}
function shouldBeRelative(from, to) {

  if(isPathRelative(to)) {
    return false
  }

  // example app/entities/Article
  const toArray = to.split('/')
  const toLayer = toArray[0]  // entities
  const toSlice = toArray[1]  // Article

  if(!toLayer || !toSlice || !layers[toLayer]) {
    return false
  }

  const normalizedPath = path.toNamespacedPath(from)
  const projectFrom = normalizedPath.split('src')[1]
  const fromArray = projectFrom.split('\\')
  const fromLayer = fromArray[1]
  const fromSlice = fromArray[2]

  if(!fromLayer || !fromSlice || !layers[fromLayer]) {
    return false
  }

  return fromSlice === toSlice && toLayer === fromLayer

  // example C:\Users\impudev\Desktop\javascript\project\src\entities\Article
  const fromFilename = context.getFilename()
}
